local dirY = 400

local p1 = {x=200, y=350}
local p2 = {x=525, y=300}

local function getParabolaCrossPoint (p1x, p1y, p2x, p2y, dirY)
	local f1 = math.abs(dirY-p1y)/2
	local f2 = math.abs(dirY-p2y)/2

	local a1 = -1/(4*f1)
	local a2 = -1/(4*f2)
	local b1 = -2*p1x*a1
	local b2 = -2*p2x*a2
	local c1 = p1x*p1x*a1 + p1y + f1
	local c2 = p2x*p2x*a2 + p2y + f2
	local a = a1-a2
	local b = b1-b2
	local c = c1-c2

	local d = b*b-4*a*c
	local x, y
	if d >=0 then
		x = (-b-math.sqrt (d))/(2*a)
		y = a1*x*x + b1*x + c1
	end
	return x, y
end

local function getParabolaLine (x, y, dirY, xMin, xMax) -- focus, directrix, 
	local line = {}
	local f = math.abs(dirY-y)/2
	local a = -1/(4*f) 
	local b = -2*x*a
	local c = x*x*a + y + f
	local nSteps = math.floor((xMax-xMin)/5)
	local step = (xMax-xMin)/nSteps
	for i = 0, nSteps do
		local x0 = xMin + i * step
		local y0 = a*x0*x0 + b*x0 + c
		table.insert (line, x0)
		table.insert (line, y0)
	end
	return line
end

function love.load ()
	local px, py = getParabolaCrossPoint (p1.x, p1.y, p2.x, p2.y, dirY)
	cross = {x=px, y=py}

	p1.line = getParabolaLine (p1.x, p1.y, dirY, 0, cross.x)
	p2.line = getParabolaLine (p2.x, p2.y, dirY, cross.x, 800)
end

function love.draw ()
	if #p1.line > 3 then
		love.graphics.line (p1.line)
	end
	if #p2.line > 3 then
		love.graphics.line (p2.line)
	end
	love.graphics.circle ('line', cross.x, cross.y, 5)
	love.graphics.line (0, dirY, 800, dirY)
end


function love.mousemoved(x, y)
	p2.x, p2.y = x, y

	local px, py = getParabolaCrossPoint (p1.x, p1.y, p2.x, p2.y, dirY)
	if px then
		cross.x, cross.y = px, py
		love.window.setTitle (px..' '..py)
		p1.line = getParabolaLine (p1.x, p1.y, dirY, 0, px)
		p2.line = getParabolaLine (p2.x, p2.y, dirY, px, 800)
	end
end

function love.keypressed(key, scancode, isrepeat)
	if key == "escape" then
		love.event.quit()
	end
end